@@ -27,6 +27,8 @@ from .exec import (
     insert_from_csv,
     insert_from_df,
     insert_from_json,
+    truncate,
+    drop,
     get_connection,
     close,
 )
