@@ -13,7 +13,16 @@ MYSQL, POSTGRESQL, ORACLE, SQL_SERVER, SQLITE, UNKNOW = 'MySQL', 'PostgreSQL', '
 MYSQLCLIENT_DRIVER, PYMYSQL_DRIVER, MYSQL_CONNECTOR_DRIVER, PSYCOPG2_DRIVER, PG8000_DRIVER, PY_POSTGRESQL_DRIVER, PYGRESQL_DRIVER, ORACLEDB_DRIVER,\
     SQLITE3_DRIVER = 'MySQLdb', 'pymysql', 'mysql.connector', 'psycopg2', 'pg8000', 'postgresql.driver.dbapi20', 'pgdb', 'oracledb', 'sqlite3'
 
-DRIVERS = {MYSQLCLIENT_DRIVER: MYSQL, PYMYSQL_DRIVER: MYSQL, MYSQL_CONNECTOR_DRIVER: MYSQL, PSYCOPG2_DRIVER: POSTGRESQL, PG8000_DRIVER: POSTGRESQL,\
-           PY_POSTGRESQL_DRIVER: POSTGRESQL, PYGRESQL_DRIVER: POSTGRESQL, ORACLEDB_DRIVER: ORACLE, SQLITE3_DRIVER: SQLITE}
+DRIVERS = {
+    MYSQLCLIENT_DRIVER: MYSQL,
+    PYMYSQL_DRIVER: MYSQL,
+    MYSQL_CONNECTOR_DRIVER: MYSQL,
+    PSYCOPG2_DRIVER: POSTGRESQL,
+    PG8000_DRIVER: POSTGRESQL,
+    PY_POSTGRESQL_DRIVER: POSTGRESQL,
+    PYGRESQL_DRIVER: POSTGRESQL,
+    ORACLEDB_DRIVER: ORACLE,
+    SQLITE3_DRIVER: SQLITE
+}
 
 PARAM_DRIVER, PARAM_SHOW_SQL, PARAM_TRANS_PLACEHOLDER, PARAM_DEBUG, PARAM_POOL_SIZE, PARAM_PORT = 'driver', 'show_sql', 'trans_placeholder', 'debug', 'pool_size', 'port'
