@@ -142,7 +142,7 @@ def execute(sql: str, *args, **kwargs):
          INSERT INTO person(name, age) VALUES(:name,:age)  -->  kwargs: {'name': '张三', 'age': 20}
     """
     sql, args = try_mapping('sqlexec.execute', sql, *args, **kwargs)
-    return do_execute(sql, *args)
+    return _execute(None, sql, *args)
 
 
 def insert(table_name: str, **kwargs):
@@ -155,7 +155,7 @@ def insert(table_name: str, **kwargs):
     """
     insert_log('insert', table_name, **kwargs)
     sql, args = sql_support.insert_sql_args(table_name.strip(), **kwargs)
-    return execute(sql, *args)
+    return _execute(None, sql, *args)
 
 
 def save(select_key: str, table_name: str, **kwargs) -> int:
@@ -169,7 +169,7 @@ def save(select_key: str, table_name: str, **kwargs) -> int:
     """
     save_log('save', select_key, table_name, **kwargs)
     sql, args = sql_support.insert_sql_args(table_name.strip(), **kwargs)
-    return save_sql(select_key, sql, *args)
+    return _execute(select_key, sql, *args)
 
 
 def save_sql(select_key: str, sql: str, *args, **kwargs):
@@ -184,7 +184,7 @@ def save_sql(select_key: str, sql: str, *args, **kwargs):
     """
     logger.debug("Exec func 'sqlexec.%s', 'select_key': %s \n\t sql: %s \n\t args: %s \n\t kwargs: %s" % ('save_sql', select_key, sql, args, kwargs))
     sql, args = sql_support.get_mapping_sql_args(sql, *args, **kwargs)
-    return do_save_sql(select_key, sql, *args)
+    return _execute(select_key, sql, *args)
 
 
 def get(sql: str, *args, **kwargs):
@@ -446,10 +446,20 @@ def insert_from_json(file_name: str, table_name: str, encoding='utf-8'):
     elif isinstance(data, Iterable):
         return batch_insert(table_name, data)
     else:
-        logger.info("Exec func 'sqlexec.%s' \n\t Table: '%s' insert 0 rows." % ('insert_from_json', table_name ))
+        logger.info("Exec func 'sqlexec.%s' \n\t Table: '%s' insert 0 rows." % ('insert_from_json', table_name))
         return 0
 
 
+def truncate(table_name: str) -> int:
+    """ sqlexec.truncate('person') """
+    return _execute(None, 'TRUNCATE TABLE %s' % table_name)
+
+
+def drop(table_name: str) -> int:
+    """ sqlexec.drop('person') """
+    return _execute(None, 'DROP TABLE %s' % table_name)
+
+
 def get_connection():
     global _DB_CTX
     _DB_CTX.try_init()
