@@ -7,11 +7,69 @@ from .constant import LIMIT_1, SELECT_COUNT
 from typing import Sequence, Union, List, Tuple
 
 
+class ColumnWhereExec:
+
+    def __init__(self, where_exec, *columns):
+        self._where_exec = where_exec
+        self.columns = columns
+
+    def get(self):
+        """
+        Execute select SQL and expected one int and only one int result, SQL contain 'limit'.
+        MultiColumnsError: Expect only one column.
+
+        sqlexec.table('person').columns('name').where(id=1).get()
+        """
+        return self._where_exec.get(self.columns[0])
+
+    def select(self):
+        """
+        sqlexec.table('person').columns('name', 'age').where(name='李四').select()
+        """
+        return self._where_exec.select(*self.columns)
+
+    def select_one(self):
+        """
+        sqlexec.table('person').columns('name', 'age').where(name='李四').select_one()
+        """
+        return self._where_exec.select_one(*self.columns)
+
+    def query(self):
+        """
+        sqlexec.table('person').columns('name', 'age').where(name='李四').query()
+        """
+        return self._where_exec.query(*self.columns)
+
+    def query_one(self):
+        """
+        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').query_one()
+        """
+        return self._where_exec.query_one(*self.columns)
+
+    def to_csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
+        """
+        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').csv('test.csv')
+        """
+        self._where_exec.load(*self.columns).to_csv(file_name, delimiter, header, encoding)
+
+    def to_df(self):
+        """
+        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').df()
+        """
+        return self._where_exec.load(*self.columns).to_df()
+
+    def to_json(self, file_name: str, encoding='utf-8'):
+        """
+        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').json('test.json')
+        """
+        self._where_exec.load(*self.columns).to_json(file_name, encoding)
+
+
 class WhereExec:
 
     def __init__(self, table_name, **kwargs):
         self.table = table_name
-        self.where_condition = kwargs
+        self._where_condition = kwargs
 
     def get(self, column: str):
         """
@@ -20,7 +78,7 @@ class WhereExec:
 
         sqlexec.table('person').where(name='李四').get('id')
         """
-        where, args, _ = get_where_arg_limit(**self.where_condition)
+        where, args, _ = get_where_arg_limit(**self._where_condition)
         sql = get_select_sql(self.table, where, LIMIT_1, column)
         return exec.do_get(sql, *args, LIMIT_1)
 
@@ -34,7 +92,7 @@ class WhereExec:
         """
         sqlexec.table('person').where(name='李四').select('name', 'age')
         """
-        where, args, limit = get_where_arg_limit(**self.where_condition)
+        where, args, limit = get_where_arg_limit(**self._where_condition)
         sql = get_select_sql(self.table, where, limit, *columns)
         if limit:
             if isinstance(limit, int):
@@ -47,7 +105,7 @@ class WhereExec:
         """
         sqlexec.table('person').where(name='李四').select_one('name', 'age')
         """
-        where, args, _ = get_where_arg_limit(**self.where_condition)
+        where, args, _ = get_where_arg_limit(**self._where_condition)
         sql = get_select_sql(self.table, where, LIMIT_1, *columns)
         return exec.do_select_one(sql, *args, LIMIT_1)
 
@@ -55,7 +113,7 @@ class WhereExec:
         """
         sqlexec.table('person').where(name='李四').query('name', 'age')
         """
-        where, args, limit = get_where_arg_limit(**self.where_condition)
+        where, args, limit = get_where_arg_limit(**self._where_condition)
         sql = get_select_sql(self.table, where, limit, *columns)
         if limit:
             if isinstance(limit, int):
@@ -68,7 +126,7 @@ class WhereExec:
         """
         sqlexec.table('person').where(name__eq='李四').query_one('name', 'age')
         """
-        where, args, _ = get_where_arg_limit(**self.where_condition)
+        where, args, _ = get_where_arg_limit(**self._where_condition)
         sql = get_select_sql(self.table, where, LIMIT_1, *columns)
         return exec.do_query_one(sql, *args, LIMIT_1)
 
@@ -76,7 +134,7 @@ class WhereExec:
         """
         sqlexec.table('person').where(name='李四').delete()
         """
-        where, args, _ = get_where_arg_limit(**self.where_condition)
+        where, args, _ = get_where_arg_limit(**self._where_condition)
         sql = 'DELETE FROM %s %s' % (self.table, where)
         return exec.do_execute(sql, *args)
 
@@ -84,7 +142,7 @@ class WhereExec:
         """
         sqlexec.table('person').where(name='张三').update(name='李四', age=45)
         """
-        where, args, _ = get_where_arg_limit(**self.where_condition)
+        where, args, _ = get_where_arg_limit(**self._where_condition)
         update_cols, update_args = zip(*kwargs.items())
         args = [*update_args, *args]
         update_cols = ', '.join(['{} = ?'.format(col) for col in update_cols])
@@ -95,7 +153,7 @@ class WhereExec:
         """
         sqlexec.table('person').where(name='张三').load('name', 'age')
         """
-        where, args, limit = get_where_arg_limit(**self.where_condition)
+        where, args, limit = get_where_arg_limit(**self._where_condition)
         sql = get_select_sql(self.table, where, limit, *columns)
         if limit:
             if isinstance(limit, int):
@@ -104,69 +162,14 @@ class WhereExec:
                 args = [*args, *limit]
         return exec.do_load(sql, *args)
 
-
-class ColumnWhereExec:
-
-    def __init__(self, where_exec, *columns):
-        self.where_exec = where_exec
-        self.columns = columns
-
-    def get(self):
-        """
-        Execute select SQL and expected one int and only one int result, SQL contain 'limit'.
-        MultiColumnsError: Expect only one column.
-
-        sqlexec.table('person').columns('name').where(id=1).get()
-        """
-        return self.where_exec.get(self.columns[0])
-
-    def select(self):
-        """
-        sqlexec.table('person').columns('name', 'age').where(name='李四').select('name', 'age')
-        """
-        return self.where_exec.select(*self.columns)
-
-    def select_one(self):
-        """
-        sqlexec.table('person').columns('name', 'age').where(name='李四').select_one('name', 'age')
-        """
-        return self.where_exec.select_one(*self.columns)
-
-    def query(self):
-        """
-        sqlexec.table('person').columns('name', 'age').where(name='李四').query('name', 'age')
-        """
-        return self.where_exec.query(*self.columns)
-
-    def query_one(self):
-        """
-        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').query_one()
-        """
-        return self.where_exec.query_one(*self.columns)
-
-    def to_csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
-        """
-        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').csv('test.csv')
-        """
-        self.where_exec.load(*self.columns).to_csv(file_name, delimiter, header, encoding)
-
-    def to_df(self):
-        """
-        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').df()
-        """
-        return self.where_exec.load(*self.columns).to_df()
-
-    def to_json(self, file_name: str, encoding='utf-8'):
-        """
-        sqlexec.table('person').columns('name', 'age').where(name__eq='李四').json('test.json')
-        """
-        self.where_exec.load(*self.columns).to_json(file_name, encoding)
+    def columns(self, *columns) -> ColumnWhereExec:
+        return ColumnWhereExec(self, *columns)
 
 
 class ColumnExec:
 
     def __init__(self, table_exec, *columns):
-        self.table_exec = table_exec
+        self._table_exec = table_exec
         self.columns = columns
 
     def insert(self, *args):
@@ -177,7 +180,7 @@ class ColumnExec:
 
         :param args: ('张三', 20)
         """
-        sql = sql_support.insert_sql(self.table_exec.table.strip(), self.columns)
+        sql = sql_support.insert_sql(self._table_exec.table.strip(), self.columns)
         return exec.execute(sql, *args)
 
     def batch_insert(self, *args):
@@ -188,59 +191,59 @@ class ColumnExec:
 
         :param args: [('张三', 20), ('李四', 28)]
         """
-        sql = sql_support.insert_sql(self.table_exec.table.strip(), self.columns)
+        sql = sql_support.insert_sql(self._table_exec.table.strip(), self.columns)
         return exec.batch_execute(sql, *args)
 
     def get(self):
         """
         sqlexec.table('person').columns('count(1)').get()
         """
-        return self.table_exec.get(*self.columns)
+        return self._table_exec.get(*self.columns)
 
     def select(self):
         """
         sqlexec.table('person').columns('name', 'age').select()
         """
-        return self.table_exec.select(*self.columns)
+        return self._table_exec.select(*self.columns)
 
     def select_one(self):
         """
         sqlexec.table('person').columns('name', 'age').select_one()
         """
-        return self.table_exec.select_one(*self.columns)
+        return self._table_exec.select_one(*self.columns)
 
     def query(self):
         """
         sqlexec.table('person').columns('name', 'age').query()
         """
-        return self.table_exec.query(*self.columns)
+        return self._table_exec.query(*self.columns)
 
     def query_one(self):
         """
         sqlexec.table('person').columns('name', 'age').query_one()
         """
-        return self.table_exec.query_one(*self.columns)
+        return self._table_exec.query_one(*self.columns)
 
     def to_csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
         """
         sqlexec.table('person').columns('name', 'age').to_csv('test.csv')
         """
-        self.table_exec.load(*self.columns).to_csv(file_name, delimiter, header, encoding)
+        self._table_exec.load(*self.columns).to_csv(file_name, delimiter, header, encoding)
 
     def to_df(self):
         """
         sqlexec.table('person').columns('name', 'age').to_df()
         """
-        return self.table_exec.load(*self.columns).to_df()
+        return self._table_exec.load(*self.columns).to_df()
 
     def to_json(self, file_name: str, encoding='utf-8'):
         """
         sqlexec.table('person').columns('name', 'age').to_json('test.json')
         """
-        self.table_exec.load(*self.columns).to_json(file_name, encoding)
+        self._table_exec.load(*self.columns).to_json(file_name, encoding)
 
     def where(self, **kwargs) -> ColumnWhereExec:
-        return ColumnWhereExec(self.table_exec.where(**kwargs), *self.columns)
+        return ColumnWhereExec(self._table_exec.where(**kwargs), *self.columns)
 
 
 class TableExec:
@@ -343,6 +346,14 @@ class TableExec:
         """
         return exec.insert_from_json(file_name, self.table, encoding=encoding)
 
+    def truncate(self) -> int:
+        """ sqlexec.table('person').truncate() """
+        return exec.truncate(self.table)
+
+    def drop(self) -> int:
+        """ sqlexec.table('person').drop() """
+        return exec.drop(self.table)
+
     def where(self, **kwargs) -> WhereExec:
         return WhereExec(self.table, **kwargs)
 
